@@ -1,6 +1,3 @@
-//go:build linux
-// +build linux
-
 /*
    Copyright The containerd Authors.
 
@@ -23,7 +20,7 @@ import (
 	"testing"
 
 	"github.com/stretchr/testify/require"
-	runtime "k8s.io/cri-api/pkg/apis/runtime/v1alpha2"
+	runtime "k8s.io/cri-api/pkg/apis/runtime/v1"
 )
 
 func TestRunPodSandboxWithoutMetadata(t *testing.T) {
@@ -35,16 +32,9 @@ func TestRunPodSandboxWithoutMetadata(t *testing.T) {
 }
 
 func TestCreateContainerWithoutMetadata(t *testing.T) {
-	sbConfig := PodSandboxConfig("sandbox", "container-create")
-	sb, err := runtimeService.RunPodSandbox(sbConfig, *runtimeHandler)
-	require.NoError(t, err)
-	defer func() {
-		// Make sure the sandbox is cleaned up in any case.
-		runtimeService.StopPodSandbox(sb)
-		runtimeService.RemovePodSandbox(sb)
-	}()
+	sb, sbConfig := PodSandboxConfigWithCleanup(t, "sandbox", "container-create")
 	config := &runtime.ContainerConfig{}
-	_, err = runtimeService.CreateContainer(sb, config, sbConfig)
+	_, err := runtimeService.CreateContainer(sb, config, sbConfig)
 	require.Error(t, err)
 	_, err = runtimeService.Status()
 	require.NoError(t, err)
